@@ -17,7 +17,11 @@ NULL
 #' @param stop Boolean. Stop if not installed. If \code{FALSE} and
 #' library is not available, warning will be shown.
 #' @param load Boolean. Load library?
-#' @param ... Enabled lazyeval to ignore shared parameters.
+#' @param lib.loc Character vector. Location of R library trees
+#' to search through, or \code{NULL}. The default value of \code{NULL}
+#' corresponds to all libraries currently known to \code{.libPaths()}.
+#' Non-existent library trees are silently ignored.
+#' @param ... Pass additional parameters.
 #' @return No return value, called for side effects.
 #' @examples
 #' # Check if library base is installed. If not, stop and show error
@@ -25,10 +29,11 @@ NULL
 #' # Check if library xxx is installed. If not, show warning
 #' try_require("xxx", stop = FALSE)
 #' @export
-try_require <- function(package, stop = TRUE, load = TRUE, ...) {
+try_require <- function(package, stop = TRUE, load = TRUE, lib.loc = NULL, ...) {
   present <- length(find.package(package, quiet = TRUE)) > 0
   if (present & load) {
-    suppressPackageStartupMessages(library(package, character.only = TRUE))
+    # Be careful: ... parameter is not enabled in library()
+    suppressPackageStartupMessages(library(package, character.only = TRUE, lib.loc = lib.loc))
   } else {
     if (stop) {
       stop(paste0("Package '", package, "' required. Install and try again."), call. = FALSE)
